@@ -1,15 +1,34 @@
+/*
+ * Licensed to Elasticsearch B.V. under one or more contributor
+ * license agreements. See the NOTICE file distributed with
+ * this work for additional information regarding copyright
+ * ownership. Elasticsearch B.V. licenses this file to you under
+ * the Apache License, Version 2.0 (the "License"); you may
+ * not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *    http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing,
+ * software distributed under the License is distributed on an
+ * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+ * KIND, either express or implied.  See the License for the
+ * specific language governing permissions and limitations
+ * under the License.
+ */
+
 import _ from 'lodash';
 import $ from 'jquery';
 import rison from 'rison-node';
-import 'ui/doc_viewer';
-import 'ui/filters/trust_as_html';
-import 'ui/filters/short_dots';
-import './table_row.less';
-import { noWhiteSpace } from '../../../../core_plugins/kibana/common/utils/no_white_space';
-import openRowHtml from 'ui/doc_table/components/table_row/open.html';
-import detailsHtml from 'ui/doc_table/components/table_row/details.html';
-import { uiModules } from 'ui/modules';
-import { disableFilter } from 'ui/filter_bar';
+import '../../doc_viewer';
+import '../../filters/trust_as_html';
+import '../../filters/short_dots';
+import { noWhiteSpace } from '../../../../legacy/core_plugins/kibana/common/utils/no_white_space';
+import openRowHtml from './table_row/open.html';
+import detailsHtml from './table_row/details.html';
+import { uiModules } from '../../modules';
+import { disableFilter } from '../../filter_bar';
+import { dispatchRenderComplete } from '../../render_complete';
 
 const module = uiModules.get('app/discover');
 
@@ -42,7 +61,7 @@ module.directive('kbnTableRow', function ($compile, $httpParamSerializer, kbnUrl
       onRemoveColumn: '=?',
     },
     link: function ($scope, $el) {
-      $el.after('<tr>');
+      $el.after('<tr data-test-subj="docTableDetailsRow">');
       $el.empty();
 
       // when we compile the details, we use this $scope
@@ -159,7 +178,7 @@ module.directive('kbnTableRow', function ($compile, $httpParamSerializer, kbnUrl
           const $target = reuse ? $(reuse).detach() : $(html);
           $target.data('discover:html', html);
           const $before = $cells.eq(i - 1);
-          if ($before.size()) {
+          if ($before.length) {
             $before.after($target);
           } else {
             $el.append($target);
@@ -180,7 +199,7 @@ module.directive('kbnTableRow', function ($compile, $httpParamSerializer, kbnUrl
 
         // trim off cells that were not used rest of the cells
         $cells.filter(':gt(' + (newHtmls.length - 1) + ')').remove();
-        $el.trigger('renderComplete');
+        dispatchRenderComplete($el[0]);
       }
 
       /**
